==> qore-0.9.4.1.tar.bz2: qore-0.9.4.1/docs/modules/SalesforceRestDataProvider/html/class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.js <==
var class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider =
[
    [ "constructor", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a556c4e916005bdeb21e0023b2348d2e7", null ],
    [ "createRecordImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a9205f6d4f7683c2733ee31f1aeb6ad77", null ],
    [ "deleteRecordsImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a738af964e68a06a3e43fcf6fdd254fd2", null ],
    [ "deleteSingleRecord", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a59080955a1d4f299575322335576a88b", null ],
    [ "getName", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a21a391db62cc6049de539505bee22c94", null ],
    [ "getRecordInfoIntern", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#ac4b1fc5ad0f46f4d5232cf4c4fe336db", null ],
    [ "getStaticInfoImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a42448fbdefd17d59e23a80c7ea052fc8", null ],
    [ "record_info", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#aa77f9d822f07cde350f33ad5e56c978c", null ],
    [ "searchRecordsImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a369a70299be9929c49745e655de20146", null ],
    [ "updateRecordsImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a6f8e168372fcfdad40206037b0aea9b7", null ],
    [ "updateSingleRecord", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a97c66f9b1ccfe5acaa402dcbcd880d26", null ],
    [ "upsertRecordImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#ad095e3d9ea1c4831becfc43bb1091393", null ],
    [ "desc", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a004c108c00b9edb9f6f5bb06941f98e1", null ],
    [ "name", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#af77781fabf089e0b8dc1611adb700999", null ],
    [ "rest", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a9002077bca702db31f54caa5bb3dbe2a", null ],
    [ "sobject", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a2711e4423f743c5763ac22233af04781", null ]
];

==> qore-1.0.3.tar.bz2: qore-1.0.3/docs/modules/SalesforceRestDataProvider/html/class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.js <==
var class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider =
[
    [ "constructor", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a556c4e916005bdeb21e0023b2348d2e7", null ],
    [ "createRecordImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a9205f6d4f7683c2733ee31f1aeb6ad77", null ],
    [ "deleteRecordsImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a738af964e68a06a3e43fcf6fdd254fd2", null ],
    [ "deleteSingleRecord", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a59080955a1d4f299575322335576a88b", null ],
    [ "fixSalesforceRecord", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a252a9888cdffd84462373d4783cfc811", null ],
    [ "getName", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a21a391db62cc6049de539505bee22c94", null ],
    [ "getRecordInfoIntern", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#ac4b1fc5ad0f46f4d5232cf4c4fe336db", null ],
    [ "getStaticInfoImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a42448fbdefd17d59e23a80c7ea052fc8", null ],
    [ "record_info", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#aa77f9d822f07cde350f33ad5e56c978c", null ],
    [ "searchRecordsImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a369a70299be9929c49745e655de20146", null ],
    [ "updateRecordsImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a6f8e168372fcfdad40206037b0aea9b7", null ],
    [ "updateSingleRecord", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a97c66f9b1ccfe5acaa402dcbcd880d26", null ],
    [ "upsertRecordImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#ad095e3d9ea1c4831becfc43bb1091393", null ],
    [ "desc", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a004c108c00b9edb9f6f5bb06941f98e1", null ],
    [ "name", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#af77781fabf089e0b8dc1611adb700999", null ],
    [ "rest", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a9002077bca702db31f54caa5bb3dbe2a", null ],
    [ "sobject", "class_salesforce_rest_data_provider_1_1_salesforce_rest_object_data_provider.html#a2711e4423f743c5763ac22233af04781", null ]
];
